defmodule ProptrackerWeb.RecommendedPriceContext do
  use WhiteBread.Context
  use Hound.Helpers
  import Plug.Conn
  alias Proptracker.Repo
  alias Proptracker.Advertisements
  alias Proptracker.Accounts.User

  scenario_starting_state fn state ->
    # Start a new Hound session for each scenario
    Hound.start_session()
    state
  end

  scenario_finalize fn _status, _state ->
    Hound.end_session()
    :ok
  end

  # Background setup
  given_ ~r/^there is an advertisement with ID "([^"]+)"$/ do
    fn id, state ->
      {:ok, advertisement} = Advertisements.create_advertisement(%{
        id: id,
        title: "Sample Ad",
        description: "Sample description",
        price: 100000
      })
      {:ok, Map.put(state, :advertisement, advertisement)}
    end
  end

  given_ ~r/^I am on the edit advertisement page for that advertisement$/ do
    fn state ->
      advertisement = state[:advertisement]
      navigate_to("/advertisements/#{advertisement.id}/edit")
      {:ok, state}
    end
  end

  # Scenario steps
  given_ ~r/^I have filled in "([^"]+)" with "([^"]+)"$/ do
    fn field, value, state ->
      fill_field("advertisement[#{field}]", value)
      {:ok, state}
    end
  end

  given_ ~r/^I have left "([^"]+)" empty$/ do
    fn field, state ->
      fill_field("advertisement[#{field}]", "")
      {:ok, state}
    end
  end

  when_ ~r/^I click on the "Get Recommended Price" button$/ do
    fn state ->
      # Locate the button by its ID, name, or other attributes and click it
      click(find_element(:css, "#get-recommended-price"))
      {:ok, state}
    end
  end

  then_ ~r/^I should see "([^"]+)" displayed below the price field$/ do
    fn message, state ->
      assert visible_in_page?(~r/#{message}/)
      {:ok, state}
    end
  end

  then_ ~r/^the text color should be "([^"]+)"$/ do
    fn color, state ->
      assert css_property("#recommended-price", "color") == color
      {:ok, state}
    end
  end
end
