defmodule ProptrackerWeb.Features.Contexts.SoldRent do
  use WhiteBread.Context
  use ExUnit.Case, async: true
  import Plug.Conn
  import Phoenix.ConnTest

  alias Proptracker.Repo
  alias Proptracker.Accounts.Advertisement

  # Given I am a user on the homepage
  given_ ~r/^I am a user on the homepage$/ do
    fn state ->
      conn = build_conn()
      {:ok, Map.put(state, :conn, conn)}
    end
  end

  # When the homepage is loaded
  when_ ~r/^the homepage is loaded$/ do
    fn state ->
      conn = state[:conn]
      conn = get(conn, "/") # Simulate GET request to the homepage
      assert html_response(conn, 200) =~ "Welcome to the Homepage"
      {:ok, state}
    end
  end

  # Then I should see only the available properties listed
  then_ ~r/^I should see only the available properties listed$/ do
    fn state ->
      conn = state[:conn]
      advertisements = html_response(conn, 200) |> Floki.find(".advertisement-status")

      # Verify only available properties are listed
      only_available = Enum.all?(advertisements, fn ad ->
        status = Floki.text(ad)
        status == "Available"
      end)

      assert only_available, "Not all properties are available on the homepage"
      {:ok, state}
    end
  end

  # Then I should not see any reserved or sold properties on the homepage
  then_ ~r/^I should not see any reserved or sold properties on the homepage$/ do
    fn state ->
      conn = state[:conn]
      advertisements = html_response(conn, 200) |> Floki.find(".advertisement-status")

      # Verify no sold or reserved properties are listed
      no_sold_or_reserved = Enum.none?(advertisements, fn ad ->
        status = Floki.text(ad)
        status == "Sold" or status == "Reserved"
      end)

      assert no_sold_or_reserved, "Sold or reserved properties are incorrectly displayed"
      {:ok, state}
    end
  end
end
