defmodule ProptrackerWeb.ContactButtonContext do
  use WhiteBread.Context
  alias ProptrackerWeb.AdvertisementController
  alias Proptracker.Accounts.User
  @moduledoc """
  Context for Contact Button and Phone Visibility for Advertisements
  """

  # Given a user is viewing an advertisement
  given_ ~r/^I am viewing an advertisement/ do
    fn state ->
      # Simulate viewing an advertisement by setting up an example advertisement
      advertisement = %{id: 1, user_id: 1} # Assuming user_id refers to the owner
      # Fetch the user's phone number using the user_id
      user = %User{id: 1, phone_number: "123-456-7890", name: "John Doe"}

      # Add both advertisement and user info to the state
      {:ok, Map.put(state, :advertisement, advertisement)
             |> Map.put(:user, user)}
    end
  end

  # Then I see the 'Contact' button
  then_ ~r/^I see the 'Contact' button$/ do
    fn state ->
      advertisement = state[:advertisement]
      user = state[:user]

      # Verify that the 'Contact' button is present (this could be part of HTML rendering check)
      assert advertisement != nil
      assert user != nil
      assert user.phone_number != nil

      {:ok, state}
    end
  end

  # Then I see the owner's phone number
  then_ ~r/^I see the owner's phone number$/ do
    fn state ->
      user = state[:user]

      # Verify that the owner's phone number is visible
      assert user.phone_number == "123-456-7890"

      {:ok, state}
    end
  end

  # When I click the 'Contact' button
  when_ ~r/^I click the 'Contact' button$/ do
    fn state ->
      advertisement = state[:advertisement]
      user = state[:user]

      # Simulate the user clicking the 'Contact' button to reveal the phone number
      # No actual change required since the phone number is already visible
      updated_user = %User{user | phone_number: user.phone_number}

      {:ok, Map.put(state, :user, updated_user)}
    end
  end
end
