defmodule ProptrackerWeb.HeaderLinksContext do
  use WhiteBread.Context
  alias Proptracker.Repo
  alias Proptracker.Accounts.User
  import Phoenix.ConnTest
  @moduledoc """
  Context for testing header links display based on user login state.
  """

  # Given the user is not logged in
  given_ ~r/^the user is not logged in$/ do
    fn state ->
      conn = Phoenix.ConnTest.build_conn()
      {:ok, Map.put(state, :conn, conn)}
    end
  end

  # Given the user is logged in
  given_ ~r/^the user is logged in$/ do
    fn state ->
      user_data = %{username: "testuser", password: "password123", password_confirmation: "password123"}
      changeset = User.registration_changeset(%User{}, user_data)
      {:ok, user} = Repo.insert(changeset)

      conn = %Plug.Conn{} |> Plug.Test.init_test_session(user_id: user.id)
      {:ok, Map.put(state, :user, user) |> Map.put(state, :conn, conn)}
    end
  end

  # When the user navigates to the home page
  when_ ~r/^the user navigates to the home page$/ do
    fn state ->
      conn = state[:conn]
      response = get(conn, "/")
      {:ok, Map.put(state, :response, response)}
    end
  end

  # Then the page should display "Home", "Our Team", "Login", and "Register" links
  then_ ~r/^the page should display "Home", "Our Team", "Login", and "Register" links$/ do
    fn state ->
      response = state[:response]
      html = html_response(response, 200)

      assert html =~ "Home"
      assert html =~ "Our Team"
      assert html =~ "Login"
      assert html =~ "Register"
      {:ok, state}
    end
  end

  # Then the page should not display a "Logout" link
  then_ ~r/^the page should not display a "Logout" link$/ do
    fn state ->
      response = state[:response]
      html = html_response(response, 200)

      refute html =~ "Logout"
      {:ok, state}
    end
  end

  # Then the page should display "Home", "Our Team", and "Logout" links
  then_ ~r/^the page should display "Home", "Our Team", and "Logout" links$/ do
    fn state ->
      response = state[:response]
      html = html_response(response, 200)

      assert html =~ "Home"
      assert html =~ "Our Team"
      assert html =~ "Logout"
      {:ok, state}
    end
  end

  # Then the page should not display "Login" or "Register" links
  then_ ~r/^the page should not display "Login" or "Register" links$/ do
    fn state ->
      response = state[:response]
      html = html_response(response, 200)

      refute html =~ "Login"
      refute html =~ "Register"
      {:ok, state}
    end
  end
end
