defmodule ProptrackerWeb.SocialMediaContext do
  use WhiteBread.Context
  alias Proptracker.Repo
  alias Proptracker.Accounts.Advertisement
  alias Proptracker.Accounts.User
  alias ProptrackerWeb.AdvertisementController
  import Phoenix.ConnTest, only: [html_response: 2]

  @moduledoc """
  Context for testing social media sharing functionality (Facebook) on the advertisement show page.
  """

  # Given a valid advertisement exists
  given_ ~r/^a valid advertisement exists$/ do
    fn state ->
      advertisement = %Advertisement{
        title: "Modern Apartment",
        price: Decimal.new(250_000),
        location: "Downtown",
        square_meters: 100,
        type: "Apartment",
        rooms: 3,
        pictures: ["/adverts/image1.jpg"],
        description: "A beautiful apartment in the city center.",
        state: "available",
        latitude: 40.7128,
        longitude: -74.0060
      }

      {:ok, advertisement} = Repo.insert(advertisement)
      {:ok, Map.put(state, :advertisement, advertisement)}
    end
  end

  # Given a user is logged in
  given_ ~r/^the user is logged in$/ do
    fn state ->
      user_data = %{username: "testuser", password: "password123", password_confirmation: "password123"}
      changeset = User.registration_changeset(%User{}, user_data)
      {:ok, user} = Repo.insert(changeset)

      conn = %Plug.Conn{} |> Plug.Test.init_test_session(user_id: user.id)
      {:ok, Map.put(state, :user, user) |> Map.put(state, :conn, conn)}
    end
  end

  # When the user navigates to the advertisement show page
  when_ ~r/^the user navigates to the advertisement show page$/ do
    fn state ->
      advertisement = state[:advertisement]
      conn = state[:conn]
      response = AdvertisementController.show(conn, %{"id" => advertisement.id})
      {:ok, Map.put(state, :response, response)}
    end
  end

  # Then the page should display a "Share on Facebook" button
  then_ ~r/^the page should display a "Share on Facebook" button$/ do
    fn state ->
      response = state[:response]
      # Check if the page contains the "Share on Facebook" button
      assert html_response(response, 200) =~ "Share on Facebook"
      {:ok, state}
    end
  end
end
