defmodule WhiteBreadContext do
  use WhiteBread.Context
  use Hound.Helpers

  feature_starting_state fn ->
    # Ensure all applications needed by Hound are started
    Application.ensure_all_started(:hound)
    %{page_url: "http://localhost:4001"}
  end

  scenario_starting_state fn state ->
    # Start a new Hound session for each scenario
    Hound.start_session()
    state
  end

  scenario_finalize fn _status, _state ->
    Hound.end_session()
    :ok
  end

  given_ ~r/^I navigate to the homepage$/, fn state ->
    # Navigate to the homepage using the URL defined in `feature_starting_state`
    navigate_to(state[:page_url])
    {:ok, state}
  end

  then_ ~r/^I see the Phoenix welcome message$/, fn state ->
    # Verify that the page contains the expected welcome message
    assert page_source() =~ "Peace of mind from prototype to production."
    {:ok, state}
  end
end
