defmodule ProptrackerWeb.PageController do
  use ProptrackerWeb, :controller
  alias Proptracker.Accounts.Advertisement
  alias Proptracker.Repo
  import Ecto.Query  # Importing the Ecto.Query module for query building
  alias Proptracker.Repo


  def home(conn, _params) do
    # Fetch the user_id from the session
    user_id = get_session(conn, :user_id)

    # Retrieve the current user if logged in
    current_user = if user_id, do: Repo.get(Proptracker.Accounts.User, user_id), else: nil

    # Retrieve the list of IDs of advertisements that the user is "interested" in
    interested_ads = if current_user, do: current_user.interested, else: []

    # Fetch advertisements excluding those marked as sold/rented
    advertisements =
      Advertisement
      |> where([a], a.state != "sold/rented")
      |> Repo.all()

    # Get available properties that the user is NOT interested in (i.e., not in the interested list)
    available_ads_not_interested =
      Advertisement
      |> where([a], a.state == "available" and not a.id in ^interested_ads)
      |> order_by([a], asc: a.state)
      |> Repo.all()

    # Get reserved properties that the user is NOT interested in
    reserved_ads_not_interested =
      Advertisement
      |> where([a], a.state == "reserved" and not a.id in ^interested_ads)
      |> order_by([a], asc: a.state)
      |> Repo.all()

    # Get available properties that the user is interested in
    available_ads_interested =
      Advertisement
      |> where([a], a.state == "available" and a.id in ^interested_ads)
      |> order_by([a], asc: a.state)
      |> Repo.all()

    # Get reserved properties that the user is interested in
    reserved_ads_interested =
      Advertisement
      |> where([a], a.state == "reserved" and a.id in ^interested_ads)
      |> order_by([a], asc: a.state)
      |> Repo.all()

    # Combine the results to return in the desired order
    advertisements =
      available_ads_not_interested ++
      reserved_ads_not_interested ++
      available_ads_interested ++
      reserved_ads_interested

    # Render the page with advertisements and current_user
    render(conn, "home1.html",
      advertisements: advertisements,
      current_user: current_user,
      type: nil,
      state: nil,
      location: "",
      query: "",
      min_price: "",
      max_price: "",
      min_rooms: "",
      max_rooms: "",
      layout: false
    )
  end



  @spec team(Plug.Conn.t(), any()) :: Plug.Conn.t()
  def team(conn, _params) do
    render(conn, "team.html",
      layout: false
      )
  end

end
