defmodule ProptrackerWeb.SessionController do
  use ProptrackerWeb, :controller
  alias Hex.API.User
  alias Proptracker.Accounts.User
  alias Proptracker.Repo
  alias ProptrackerWeb.Router.Helpers, as: Routes

  def new(conn, _params) do
    changeset = User.changeset(%User{}, %{})
    render(conn, "new.html", changeset: changeset)
  end
  def register(conn, _params) do
    changeset = User.changeset(%User{})
    render(conn, "register.html", changeset: changeset)
  end

  def create_user(conn, %{"user" => user_params}) do
    changeset = User.changeset(%User{}, user_params)
    case Repo.insert(changeset) do
      {:ok, user} ->
        conn
        |> put_flash(:info, "Account created successfully.")
        |> redirect(to: ~p"/login")
      {:error, changeset} ->
        conn
        |> put_flash(:error, "Error creating account.")
        |> render("register.html", changeset: changeset)
    end
  end



  @spec login(Plug.Conn.t(), map()) :: Plug.Conn.t()
  def login(conn, %{"user" => %{"username" => username, "password" => password}}) do
    user = Repo.get_by(User, username: username)
    user_id = get_session(conn, :user_id)
    IO.inspect(user_id, label: "Current session user_id")
    cond do
      user && user.password == password ->
        conn
        |> put_session(:user_id, user.id)
        |> put_flash(:info, "Logged in successfully.")
        |> redirect(to: ~p"/advertisements")

      true ->
        conn
        |> put_flash(:error, "Invalid username or password.")
        |> render("new.html", changeset: User.changeset(%User{}, %{}))
    end
  end


  def logout(conn, _params) do
    if get_session(conn, :user_id) do
      conn
      |> configure_session(drop: true)
      |> put_flash(:info, "Logged out successfully.")
      |> redirect(to: "/login")
    else
      conn
      |> put_flash(:error, "No active session to log out from.")
      |> redirect(to: "/login")
    end
  end
end
