defmodule ProptrackerWeb.AuthPlug do
  import Plug.Conn
  import Phoenix.Controller
  alias Proptracker.Accounts.User
  alias Proptracker.Repo

  def init(options), do: options

  def call(conn, _opts) do
    user_id = get_session(conn, :user_id)

    if user_id do
      # If user is logged in, load user from the database and assign it to conn
      case Repo.get(User, user_id) do  # Now using Proptracker.Repo.get/2
        nil ->
          # If user does not exist, log them out and redirect
          conn
          |> delete_session(:user_id)
          |> put_flash(:error, "Session expired. Please log in again.")
          |> redirect(to: "/login")
          |> halt()

        user ->
          # Assign current_user to the conn
          assign(conn, :current_user, user)
      end
    else
      # If user is not logged in, redirect to login page
      conn
      |> put_flash(:error, "Please log in to access this page.")
      |> redirect(to: "/login")
      |> halt()
    end
  end
end
