defmodule ProptrackerWeb.Router do
  use ProptrackerWeb, :router

  pipeline :browser do
    plug :accepts, ["html"]
    plug :fetch_session
    plug :fetch_live_flash
    plug :put_root_layout, html: {ProptrackerWeb.Layouts, :root}
    plug :protect_from_forgery
    plug :put_secure_browser_headers
  end

  pipeline :auth do
    plug ProptrackerWeb.AuthPlug
  end

  pipeline :api do
    plug :accepts, ["json"]
  end

  scope "/", ProptrackerWeb do
    pipe_through :browser

    # Registration and login routes
    get "/login", SessionController, :new, as: :session
    post "/login", SessionController, :login, as: :session
    delete "/logout", SessionController, :logout, as: :session
    get "/register", SessionController, :register, as: :session
    post "/register", SessionController, :create_user, as: :session

    get "/", PageController, :home
    get "/team", PageController, :team


    get "/prop_type", SearchController, :prop_type

    post "/advertisements/recommend_price", AdvertisementController, :recommend_price
    resources "/advertisements", AdvertisementController
    post "/advertisements/:id/change_status", AdvertisementController, :change_status
    post "/advertisements/:id/change_interest", AdvertisementController, :change_interest
    post "/advertisements/:id/toggle_favorite", AdvertisementController, :toggle_favorite
    post "/advertisements/:id/toggle_interest", AdvertisementController, :toggle_interest


    get "/my_favorites", AdvertisementController, :my_favorites

    get "/user_search", AdvertisementController, :user_search
    get "/past_searches", SearchController, :past_searches

    # owner profile
    get "/advertisements/:id/owner", UserController, :owner_profile



    # Protected routes
    pipe_through :auth
    resources "/users", UserController

  end

  # Other scopes may use custom stacks.
  # scope "/api", ProptrackerWeb do
  #   pipe_through :api
  # end

  # Enable LiveDashboard and Swoosh mailbox preview in development
  if Application.compile_env(:proptracker, :dev_routes) do
    import Phoenix.LiveDashboard.Router

    scope "/dev" do
      pipe_through :browser

      live_dashboard "/dashboard", metrics: ProptrackerWeb.Telemetry
      forward "/mailbox", Plug.Swoosh.MailboxPreview
    end
  end
end
