defmodule ProptrackerWeb.AdvertisementControllerTest do
  use ProptrackerWeb.ConnCase

  alias Proptracker.Accounts.{User, Advertisement}
  alias Proptracker.Repo

  # Valid user and advertisement attributes
  @valid_user_attrs %{name: "John Doe", username: "john_doe", password: "secret123", date_of_birth: ~D[1990-01-01]}
  @valid_advertisement_attrs %{
    title: "Sample Ad",
    pictures: ["path/to/image1.jpg", "path/to/image2.jpg"],
    description: "Sample Description",
    type: "rent",
    price: Decimal.new("1000.00"),
    square_meters: 100,
    location: "Sample City",
    rooms: 2,
    floor: 1,
    total_floors: 5,
    state: "available"
  }

  # Create user helper function
  defp create_user(_) do
    {:ok, user} = Repo.insert(%User{} |> User.changeset(@valid_user_attrs))
    %{user: user}
  end

  # Create advertisement helper function
  defp create_advertisement(%{user: user}) do
    advertisement_attrs = Map.put(@valid_advertisement_attrs, :user_id, user.id)

    {:ok, advertisement} =
      %Advertisement{}
      |> Advertisement.changeset(advertisement_attrs)
      |> Repo.insert()

    %{advertisement: advertisement}
  end

  # Login helper function
  defp login_user(conn, user) do
    post(conn, "/login", user: %{username: user.username, password: user.password})
  end

  describe "delete advertisement" do
    setup [:create_user, :create_advertisement]

    test "successfully deletes an existing advertisement", %{conn: conn, advertisement: advertisement, user: user} do
      # Step 1: Simulate logging in the user
      conn = login_user(conn, user)

      # Step 2: Verify user is logged in (session contains user_id)
      assert get_session(conn, :user_id) == user.id

      # Step 3: Simulate DELETE request to delete the advertisement
      conn = delete(conn, ~p"/advertisements/#{advertisement.id}")

      # Step 4: Assert the advertisement was deleted from the database
      assert Repo.get(Advertisement, advertisement.id) == nil

      # Step 5: Verify the redirect and flash message
      assert redirected_to(conn) == ~p"/advertisements"
      assert get_flash(conn, :info) == "Advertisement deleted successfully."
    end
  end
end
