defmodule ProptrackerWeb.AuthTest do
  use ProptrackerWeb.ConnCase, async: true

  alias Proptracker.Accounts.User
  alias Proptracker.Repo

  @valid_user_params %{
    "username" => "valid_user",  # Ensure this is a unique username
    "password" => "valid_password",
    "password_confirmation" => "valid_password"
  }

  @invalid_user_params %{
    "username" => "invalid_user",
    "password" => "short",
    "password_confirmation" => "short"
  }

  describe "User Registration" do
    test "registers a user with valid data", %{conn: conn} do
      conn = post(conn, ~p"/register", user: @valid_user_params)

      # Ensure the response status is 200 OK (successfully rendered the page)
      assert html_response(conn, 200)

      # Check the changeset before insertion
      changeset = User.changeset(%User{}, @valid_user_params)

      # Ensure the user was inserted into the database
      user = Repo.get_by(User, username: @valid_user_params["username"])
    end



    test "shows error when registration data is invalid", %{conn: conn} do
      conn = post(conn, ~p"/register", user: @invalid_user_params)

      # Ensure the registration form is re-rendered with error messages
      assert html_response(conn, 200) =~ "Error creating account"
    end
  end

  describe "User Login" do
    setup do
      # Create a valid user in the database
      valid_user = Repo.insert!(%User{
        username: "valid_user",
        password: "valid_password"
      })

      {:ok, valid_user: valid_user}
    end

    test "logs in a user with valid credentials", %{conn: conn, valid_user: valid_user} do
      conn = post(conn, ~p"/login", user: %{
        "username" => valid_user.username,
        "password" => "valid_password"
      })

      # Ensure successful login and redirect to the user's page
      assert redirected_to(conn) == ~p"/advertisements"
    end

    test "fails to log in with invalid credentials", %{conn: conn} do
      conn = post(conn, ~p"/login", user: %{
        "username" => "nonexistent_user",
        "password" => "invalid_password"
      })

      # Ensure login failure and re-render the login form with an error message
      assert html_response(conn, 200) =~ "Invalid username or password."
    end
  end
end
