defmodule ProptrackerWeb.SessionControllerTest do
  use ProptrackerWeb.ConnCase

  alias Proptracker.Accounts.User
  alias Proptracker.Repo

  @valid_attrs %{name: "John Doe", username: "john_doe", password: "secret123", date_of_birth: ~D[1990-01-01], phone_number: "123456789"}

  defp create_user(_) do
    {:ok, user} = Repo.insert(%User{} |> User.changeset(@valid_attrs))
    %{user: user}
  end

  describe "logout" do
    setup [:create_user]

    test "Logs out the user and redirects to Login ", %{conn: conn, user: user} do
      # Simulate logging in the user
      conn = post(conn, "/login", user: %{username: user.username, password: user.password})

      # Verify session contains user_id
      assert get_session(conn, :user_id) == user.id

      # Simulate logging out
      conn = delete(conn, "/logout")

      # Verify redirect and flash message
      assert redirected_to(conn) == ~p"/login"
    end

    test "Fails to logout when session is missing user_id", %{conn: conn} do
      # Simulate a connection with an empty session
      conn = build_conn() |> init_test_session(%{})

      # Attempt to log out
      conn = delete(conn, "/logout")

      # Verify the response handles the missing session gracefully
      assert redirected_to(conn) == ~p"/login"
      assert get_flash(conn, :error) == "No active session to log out from."
    end
  end
end
