defmodule ProptrackerWeb.UserControllerTest do
  use ProptrackerWeb.ConnCase

  alias Proptracker.Accounts.User
  alias Proptracker.Repo

  # Setup to create a user for testing
  setup do
    user = %User{id: 1, username: "test_user", password: "password"}
    Repo.insert!(user)
    conn = build_conn() |> assign(:current_user, user)
    {:ok, conn: conn, user: user}
  end

  test "delete user deletes a user and redirects to index", %{conn: conn, user: user} do
    # Use the actual path for deleting the user
    delete_path = "/users/#{user.id}"  # Manual path for deleting a user
    conn = delete(conn, delete_path)

    # Assert that the user is redirected to the users index page
    assert redirected_to(conn) == ~p"/login"  # Manual path for index page
  end

  test "fails to delete user when user clicks on delete but lacks permissions", %{conn: conn, user: user} do
    # Create an unauthorized user trying to delete another user
    unauthorized_user = %User{id: 2, username: "unauthorized_user", password: "password"} |> Repo.insert!()

    # Assign unauthorized user to the current session
    conn = build_conn() |> assign(:current_user, unauthorized_user)

    # Attempt to delete the user
    delete_path = "/users/#{user.id}"  # Path to delete user
    conn = delete(conn, delete_path)

    # Assert the response is a redirect (302)
    assert conn.status == 302

    # Ensure the user is redirected to the users page
    assert redirected_to(conn) == "/login"

    end


end
