defmodule ProptrackerWeb.AdvertisementControllerTest do
  use ProptrackerWeb.ConnCase, async: true
  alias Proptracker.Accounts.{User, Advertisement}
  alias Proptracker.Repo

  # Helper function to log in a user
  defp login_as(conn, user) do
    conn
    |> post("/login", %{"user" => %{
      "username" => user.username,
      "password" => "valid_password"}
    })
    |> recycle() # Recycle the connection for further requests
  end

  # Setup block for creating a valid user
  setup do
    user = Repo.insert!(%User{
      username: "valid_user",
      password: "valid_password"
    })

    {:ok, user: user}
  end


  describe "update advertisement status via button click" do
    setup %{user: user} do
      # Create an advertisement for the user
      advertisement = Repo.insert!(%Advertisement{
        title: "Test Property",
        description: "A lovely property for sale.",
        type: "sale",
        price: Decimal.new("100000"),
        square_meters: 120,
        location: "Downtown",
        rooms: 3,
        floor: 2,
        total_floors: 5,
        reference: "REF123",
        state: "available",
        user_id: user.id # Assign to the valid user
      })

      {:ok, advertisement: advertisement}
    end

    test "successfully changes status using button click", %{conn: conn, user: user, advertisement: advertisement} do
      conn =
        conn
        |> login_as(user)
        |> post("/advertisements/#{advertisement.id}/change_status", %{current_state: "available"})

      assert Repo.get!(Advertisement, advertisement.id).state == "reserved"


    end

    test "prevents status update for advertisements not owned by the user", %{conn: conn, advertisement: advertisement} do
      # Create another user
      other_user = Repo.insert!(%User{
        username: "other_user",
        password: "other_password"
      })

      conn =
        conn
        |> login_as(other_user)
        |> post("/advertisements/#{advertisement.id}/change_status", %{current_state: "reserved"})

      assert Repo.get!(Advertisement, advertisement.id).state == "sold/rented" # Original state
      #assert get_flash(conn, :error) == "You do not have permission to update this advertisement."
    end
  end
end
