defmodule Proptracker.RecommendedPriceTest do
  use Proptracker.DataCase, async: true

  alias Proptracker.Accounts.{Advertisement, User}
  alias Proptracker.Repo

  describe "get_recommended_price/4" do
    setup do
      # Insert users
      user1 = Repo.insert!(%User{name: "User 1", username: "user1", password: "hashed_pw1"})
      user2 = Repo.insert!(%User{name: "User 2", username: "user2", password: "hashed_pw2"})

      # Insert advertisements associated with the users
      ad1 =
        %Advertisement{
          title: "Ad 1",
          price: 120,
          square_meters: 100,
          rooms: 3,
          location: "Tallinn",
          user_id: user1.id
        }
        |> Repo.insert!()

      ad2 =
        %Advertisement{
          title: "Ad 2",
          price: 150,
          square_meters: 110,
          rooms: 3,
          location: "Tallinn",
          user_id: user1.id
        }
        |> Repo.insert!()

      ad3 =
        %Advertisement{
          title: "Ad 3",
          price: 130,
          square_meters: 90,
          rooms: 3,
          location: "Tallinn",
          user_id: user2.id
        }
        |> Repo.insert!()

      ad4 =
        %Advertisement{
          title: "Ad 4",
          price: 200,
          square_meters: 150,
          rooms: 4,
          location: "Tallinn",
          user_id: user2.id
        }
        |> Repo.insert!()

      %{ad1: ad1, ad2: ad2, ad3: ad3, ad4: ad4}
    end

    test "calculates the average price for similar properties", %{ad1: ad1} do
      result =
        Advertisement.get_recommended_price(
          ad1.id,
          ad1.square_meters,
          ad1.rooms,
          ad1.location
        )

      expected_average = div(150 + 130, 2)

      assert result |> Decimal.to_float() |> round() == expected_average
    end

    test "excludes the advertisement itself from the calculation", %{ad1: ad1} do
      result =
        Advertisement.get_recommended_price(
          ad1.id,
          ad1.square_meters,
          ad1.rooms,
          ad1.location
        )

      refute result == ad1.price
    end

    test "returns nil if no similar properties are found", %{ad4: ad4} do
      result =
        Advertisement.get_recommended_price(
          nil,
          ad4.square_meters,
          ad4.rooms,
          "Non-existent Location"
        )

      assert result == nil
    end

    test "works without advertisement_id (all properties are considered)", %{ad1: ad1} do
      result =
        Advertisement.get_recommended_price(
          nil,
          ad1.square_meters,
          ad1.rooms,
          ad1.location
        )

      expected_average = div(120 + 150 + 130, 3)

      assert result |> Decimal.to_float() |> round() == expected_average
    end
  end
end
