defmodule ProptrackerWeb.SearchControllerTest1 do
  use ProptrackerWeb.ConnCase

  alias Proptracker.Accounts.{Advertisement}
  alias Proptracker.Repo

  @valid_advertisement_attrs %{
    type: "rent",
    title: "Spacious Apartment",
    location: "Tallinn",
    reference: "REF-1234",
    price: 1500,
    square_meters: 75,
    rooms: 3,
    state: "available"
  }

  setup do
    {:ok, advertisement} =
      %Advertisement{}
      |> Advertisement.changeset(@valid_advertisement_attrs)
      |> Repo.insert()

    %{advertisement: advertisement}
  end

  describe "property search" do
    # Positive Test Case 1
    test "returns properties matching the search criteria", %{conn: conn, advertisement: advertisement} do
      conn =
        get(conn, "/prop_type", %{
          "submitted" => "true",
          "type" => "rent",
          "location" => "Tallinn",
          "query" => "Spacious",
          "state" => "available",
          "min_price" => "1000",
          "max_price" => "2000",
          "min_rooms" => "2",
          "max_rooms" => "4"
        })

      assert html_response(conn, 200) =~ advertisement.title
    end

    # Positive Test Case 2
    test "returns all available properties when no filters are applied", %{conn: conn, advertisement: advertisement} do
      conn =
        get(conn, "/prop_type", %{
          "submitted" => "true",
          "type" => "",
          "location" => "",
          "query" => "",
          "state" => "",
          "min_price" => "",
          "max_price" => "",
          "min_rooms" => "",
          "max_rooms" => ""
        })

      assert html_response(conn, 200) =~ advertisement.title
    end

    # Negative Test Case 1
    test "returns an error if max_price is less than min_price", %{conn: conn} do
      conn =
        get(conn, "/prop_type", %{
          "submitted" => "true",
          "type" => "rent",
          "location" => "Tallinn",
          "query" => "",
          "state" => "available",
          "min_price" => "2000",
          "max_price" => "1000",
          "min_rooms" => "",
          "max_rooms" => ""
        })

      assert redirected_to(conn) == "/"
      assert get_flash(conn, :error) == "Max price cannot be less than min price."
    end

    # Negative Test Case 2
    test "returns an error if max_rooms is less than min_rooms", %{conn: conn} do
      conn =
        get(conn, "/prop_type", %{
          "submitted" => "true",
          "type" => "rent",
          "location" => "Tallinn",
          "query" => "",
          "state" => "",
          "min_price" => "",
          "max_price" => "",
          "min_rooms" => "5",
          "max_rooms" => "3"
        })

      assert redirected_to(conn) == "/"
      assert get_flash(conn, :error) == "Max rooms cannot be less than min rooms."
    end
  end
end
